@@ -4,6 +4,7 @@
  * Copyright (C) 2010, 2011, 2012
  * Martin Lambers <marlam@marlam.de>
  * Gabriele Greco <gabrielegreco@gmail.com>
+ * Frédéric Devernay <Frederic.Devernay@inrialpes.fr>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,16 +26,15 @@
 #include <vector>
 #include <string>
 
-#ifdef __APPLE__
-#  include <OpenAL/al.h>
-#  include <OpenAL/alc.h>
-#else
+#if !defined(__APPLE__) || defined(HAVE_AL_AL_H)
 #  include <AL/al.h>
 #  include <AL/alc.h>
+#else
+#  include <OpenAL/al.h>
+#  include <OpenAL/alc.h>
 #endif
 
-#include "media_data.h"
-#include "controller.h"
+#include "dispatch.h"
 
 
 class audio_output : public controller
@@ -64,12 +64,12 @@ private:
     int64_t _ext_timer_at_last_timestamp;
     int64_t _last_reported_timestamp;
 
-    // Parameters
-    parameters _params;
-
     // Get an OpenAL source format for the audio data in blob (or throw an exception)
     ALenum get_al_format(const audio_blob &blob);
 
+    // Set source parameters
+    void set_source_parameters();
+
 public:
     audio_output();
     ~audio_output();
@@ -79,15 +79,12 @@ public:
     /* Return the name of OpenAL device i. */
     const std::string &device_name(int i) const;
 
-    /* Initialize the audio device i for output. If i is -1, the default device
+    /* Initialize the audio device i for output. If i is < 0, the default device
      * will be used. Throw an exception if this fails. */
     void init(int i = -1);
     /* Deinitialize the audio device. */
     void deinit();
 
-    /* Set parameters. */
-    void set_parameters(const parameters &params);
-
     /* To play audio, do the following:
      * - First, call required_initial_data_size() to find out the initial amount
      *   of audio data that is required.
@@ -112,6 +109,9 @@ public:
 
     /* Stop audio playback, and flush all buffers. */
     void stop();
+
+    /* Receive a notification from the dispatch. */
+    virtual void receive_notification(const notification& note);
 };
 
 #endif
